/*
Printblobs - typography display hack
Copyright (C) 2013  John Tsiombikas <nuclear@member.fsf.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
uniform sampler2D framebuf, dither_tex;
uniform int dither_levels, dither_size;

uniform float tfadein;

vec4 fetch_pixel(vec2 texcoord)
{
	float x = step(0.5, mod(texcoord.y, 0.5) / 0.5);
	float offs = mix(1.0 - tfadein, tfadein - 1.0, x);
	vec2 tc = texcoord + vec2(offs, 0.0);

	return (1.0 - step(1.0, tc.x)) * step(0.0, tc.x) * texture2D(framebuf, tc);
}

void main()
{
	float levels = float(dither_levels);

	//vec4 pixel = texture2D(framebuf, gl_TexCoord[0].xy);
	vec4 pixel = fetch_pixel(gl_TexCoord[0].xy);
	float lum = dot(pixel.xyz, vec3(0.2126, 0.7152, 0.0722));
	float coord_shift = floor(lum * levels) / levels;

	vec2 dsz2 = vec2(float(dither_size), float(dither_size));

	vec2 coord = mod(gl_FragCoord.xy, dsz2) / float(dither_size);
	coord.y = coord.y / levels + coord_shift;
	float val = texture2D(dither_tex, coord).x;

	const vec3 dark_col = vec3(0.043, 0.286, 0.337);
	const vec3 bright_col = vec3(0.965, 0.778, 0.555);

	gl_FragColor = vec4(mix(dark_col, bright_col, val), 1.0);
}
